@@ -11,6 +11,9 @@ import numpy
 import struct
 import time
 
+#Add Qblox instruments build info
+from qblox_instruments import build
+
 #Add SCPI support
 from pulsar_qcm.pulsar_qcm_scpi_ifc import pulsar_qcm_scpi_ifc
 
@@ -45,12 +48,6 @@ class pulsar_qcm_ifc(pulsar_qcm_scpi_ifc):
             Debug level is 0 and there is a version mismatch.
         """
 
-        #Build information
-        self._build = {"version": "0.3.1",
-                       "date":    "09/04/2021-16:26:45",
-                       "hash":    "0x8984F670",
-                       "dirty":   False}
-
         #Initialize parent class.
         super(pulsar_qcm_ifc, self).__init__(transport_inst, debug)
 
@@ -133,7 +130,7 @@ class pulsar_qcm_ifc(pulsar_qcm_scpi_ifc):
                                                                 "date":    idn_build_list[9].split("=")[-1],
                                                                 "hash":    idn_build_list[10].split("=")[-1],
                                                                 "dirty":   int(idn_build_list[11].split("=")[-1]) > 0},
-                                                "driver":      self._build}}
+                                                "driver":       build.get_build_info()}}
 
             return idn_dict
         except:
